@@ -1,14 +1,14 @@
 __name__ = "game2dboard"
 __package__ = "game2dboard"
-__version__ = "0.8"
+__version__ = "0.9.1"
 
 try:
     from tkinter import Tk
 except ImportError:
     from Tkinter import Tk
 
-from .Board import Board
-from .Cell import Cell
-from .ImageMap import ImageMap
-from .OutputBar import OutputBar
+from .board import Board
+from .cell import Cell
+from .imagemap import ImageMap
+from .outputbar import OutputBar
 
